:mod:`art.attacks.extraction`
=============================
.. automodule:: art.attacks.extraction

Copycat CNN
-----------
.. autoclass:: CopycatCNN
   :members:
   :special-members:

Functionally Equivalent Extraction
----------------------------------
.. autoclass:: FunctionallyEquivalentExtraction
   :members:
   :special-members:

Knockoff Nets
-------------
.. autoclass:: KnockoffNets
   :members:
   :special-members:
